@@ -24,7 +24,7 @@ class Aladhan:
     def get_calendar(
         self, 
         location: Union[Coordinates, Address, City] = None, 
-        year: int=None, month: int=None
+        year: int=None, month: int=None,
     ) -> list[Adhan]:
         """
         Get the prayer times for a specific month (current month by default) and returns a list of `adhan_api.Adhan` objects.
